"""
Examine word counts for CNN and Foxnews web articles.
"""

import pandas as pd

def main():
	infile = 'counts.csv'

	df = q1(infile)
	q2(df)
	q3(df)
	df = q4(df)
	df = q5(df)
	q6(df)
	q7(df)

def q1(infile):
	""" Read the file and save it to df.  Return df to main function. """
	df = pd.read_csv(infile)
	return df

def q2(df):
	""" Print out the last two rows. """
	df[-2:]

def q3(df):
	""" Print the top 5 most frequent terms for CNN and Fox. """
	print df.sort_values('CNN', ascending = False)[['term', 'CNN']][:5]
	print df.sort_values('Fox', ascending = False)[['term', 'Fox']][:5]

def q4(df):
	""" Remove missing values for term. """
	# Option 1:
	df = df[df['term'].notnull()]
	# Option 2:
	df = df.dropna(subset = ['term'])
	return df

def q5(df):
	""" Calculate the percentage for each term and news source (divide by the total terms for the site).
	"Melt" the dataset to have a row for each term and a column for site.  That is, make the data long-form.
	"""
	df['CNN'] = (df['CNN'] / df['CNN'].sum()) * 100
	df['Fox'] = (df['Fox'] / df['Fox'].sum()) * 100
	df = pd.melt(df, id_vars = 'term', var_name = 'site', value_name = 'term_pct')
	return df

def q6(df):
	""" Now print the top 5 most frequent terms for CNN and Fox (should be the same terms). """
	print df[df['site'] == 'CNN'].sort_values('term_pct', ascending = False)[['term', 'term_pct']][:5]
	print df[df['site'] == 'Fox'].sort_values('term_pct', ascending = False)[['term', 'term_pct']][:5]

def q7(df):
	""" Find the words in each site's top 10 that are not in the top 10 of the other site. """
	cnn10 = df[df['site'] == 'CNN'].sort_values('term_pct', ascending = False)['term'][:10].tolist()
	fox10 = df[df['site'] == 'Fox'].sort_values('term_pct', ascending = False)['term'][:10].tolist()

	top_CNN = [c for c in cnn10 if c not in fox10][:5]
	top_Fox = [c for c in fox10 if c not in cnn10][:5]
	
	print top_CNN
	print top_Fox

if __name__ == "__main__":
	main()